"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _icons = require("../assets/icons");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const ANIMATION_DURATION = 250;
const USE_NATIVE_DRIVER = false;

const DropDown = props => {
  const {
    height = 100,
    label,
    items,
    selectedItem,
    theme,
    onItemSelect
  } = props;

  const dropdownRef = _react.default.useRef(null);

  const containerHeight = _react.default.useRef(new _reactNative.Animated.Value(0)).current;

  const opacityAnim = containerHeight.interpolate({
    inputRange: [0, height],
    outputRange: [1, 0],
    extrapolate: 'clamp'
  });

  const [visible, setVisible] = _react.default.useState(false);

  const startExpandAnimation = callback => {
    _reactNative.Animated.timing(containerHeight, {
      toValue: height,
      duration: ANIMATION_DURATION,
      useNativeDriver: USE_NATIVE_DRIVER
    }).start(callback);
  };

  const startCollapseAnimation = callback => {
    _reactNative.Animated.timing(containerHeight, {
      toValue: 0,
      duration: ANIMATION_DURATION,
      useNativeDriver: USE_NATIVE_DRIVER
    }).start(callback);
  };

  _react.default.useEffect(() => {
    if (visible) {
      startExpandAnimation();
    } else {
      startCollapseAnimation();
    }
  }, [visible]);

  const toggleDropdown = () => {
    if (items && items.length > 0) {
      setVisible(prevState => !prevState);
    }
  };

  const onItemPress = item => {
    onItemSelect === null || onItemSelect === void 0 ? void 0 : onItemSelect(item);
    setVisible(false);
  };

  const renderItem = _ref => {
    let {
      item
    } = _ref;
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      activeOpacity: 0.8,
      style: [styles.item, {
        backgroundColor: theme === null || theme === void 0 ? void 0 : theme.itemBackgroundColor
      }],
      onPress: () => onItemPress(item)
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: [styles.itemText, {
        color: theme === null || theme === void 0 ? void 0 : theme.itemTextColor,
        fontSize: theme === null || theme === void 0 ? void 0 : theme.itemTextSize,
        fontFamily: theme === null || theme === void 0 ? void 0 : theme.font
      }]
    }, item.label), item.label === (selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.label) && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: [styles.itemDot, {
        backgroundColor: theme === null || theme === void 0 ? void 0 : theme.itemSelectedColor
      }]
    }));
  };

  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    ref: dropdownRef,
    style: [styles.container]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    activeOpacity: 0.8,
    style: [styles.header, {
      backgroundColor: theme === null || theme === void 0 ? void 0 : theme.headerBackgroundColor,
      borderTopLeftRadius: theme === null || theme === void 0 ? void 0 : theme.cornerRadius,
      borderTopRightRadius: theme === null || theme === void 0 ? void 0 : theme.cornerRadius
    }],
    onPress: toggleDropdown
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: [styles.headerText, {
      color: theme === null || theme === void 0 ? void 0 : theme.headerTextColor,
      fontSize: theme === null || theme === void 0 ? void 0 : theme.headerTextSize,
      fontFamily: theme === null || theme === void 0 ? void 0 : theme.font
    }]
  }, label), /*#__PURE__*/_react.default.createElement(_icons.IconChevronDown, {
    style: [styles.icon, {
      transform: [{
        scaleY: visible ? -1 : 1
      }]
    }],
    size: 20,
    color: theme === null || theme === void 0 ? void 0 : theme.headerTextColor
  })), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      width: '100%',
      height: height,
      justifyContent: 'center',
      alignItems: 'center',
      backgroundColor: theme === null || theme === void 0 ? void 0 : theme.backgroundColor
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.Text, {
    style: {
      position: 'absolute',
      color: theme === null || theme === void 0 ? void 0 : theme.textColor,
      fontSize: theme === null || theme === void 0 ? void 0 : theme.textSize,
      fontFamily: theme === null || theme === void 0 ? void 0 : theme.font,
      opacity: opacityAnim
    }
  }, selectedItem && selectedItem.label || 'None'), /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [styles.dropdown, {
      height: containerHeight
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.FlatList, {
    data: items,
    renderItem: renderItem,
    keyExtractor: index => index.toString()
  }))));
};

var _default = DropDown;
exports.default = _default;

const styles = _reactNative.StyleSheet.create({
  container: {
    flex: 1
  },
  header: {
    flexDirection: 'row',
    alignItems: 'center',
    backgroundColor: 'rgba(10,10,10,0.7)',
    height: 40,
    borderTopLeftRadius: 10,
    borderTopRightRadius: 10,
    padding: 10,
    zIndex: 1
  },
  headerText: {
    flex: 1,
    textAlign: 'center',
    color: '#fafafa'
  },
  icon: {},
  dropdown: { ..._reactNative.StyleSheet.absoluteFillObject
  },
  item: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    paddingHorizontal: 16,
    paddingVertical: 10,
    borderBottomWidth: 1
  },
  itemText: {
    fontSize: 14,
    color: '#fafafa'
  },
  itemDot: {
    width: 8,
    height: 8,
    borderRadius: 4
  },
  selectedText: {
    position: 'absolute'
  }
});
//# sourceMappingURL=DropDown.js.map