"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _icons = require("../assets/icons");

var _StringUtil = require("../utils/StringUtil");

var _FooterControl = _interopRequireDefault(require("./FooterControl"));

var _GestureView = _interopRequireWildcard(require("./GestureView"));

var _TipView = _interopRequireDefault(require("./TipView"));

var _MoreControl = _interopRequireDefault(require("./MoreControl"));

var _Theme = require("../utils/Theme");

var _HeaderControl = _interopRequireDefault(require("./HeaderControl"));

var _LineSeekBar = _interopRequireDefault(require("./LineSeekBar"));

var _SpeedControl = _interopRequireDefault(require("./SpeedControl"));

var _TrackControl = _interopRequireDefault(require("./TrackControl"));

var _PlayButton = _interopRequireDefault(require("./PlayButton"));

var _Loader = _interopRequireDefault(require("./Loader"));

var _ColorUtil = require("../utils/ColorUtil");

var _reactNativeVideo = _interopRequireWildcard(require("react-native-video"));

var _ComponentUtil = require("../utils/ComponentUtil");

var _PlaylistControl = _interopRequireDefault(require("./PlaylistControl"));

var _PosterView = _interopRequireDefault(require("./PosterView"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const {
  NexenPlayerModule
} = _reactNative.NativeModules;
const ANIMATION_DURATION = 300;
const USE_NATIVE_DRIVER = false;
const FORWARD_OR_REWIND_DURATION = 10;
const RESIZE_MODES = ['BEST_FIT', 'FIT_TO_SCREEN', 'FILL_TO_SCREEN'];
const RESIZE_MODE_VALUES = ['contain', 'cover', 'stretch'];

const NexenPlayer = /*#__PURE__*/_react.default.forwardRef((props, ref) => {
  var _nexenTheme$tagView, _nexenTheme$tagView2, _nexenTheme$colors, _nexenTheme$tagView3, _nexenTheme$colors2, _nexenTheme$tipView, _nexenTheme$tipView2, _nexenTheme$tipView3, _nexenTheme$colors3, _nexenTheme$tipView4, _nexenTheme$colors4, _nexenTheme$sizes, _nexenTheme$colors5, _nexenTheme$colors6;

  let {
    source: playerSource,
    config: playerConfig,
    playList: playerPlayList,
    style,
    insets,
    theme,
    onBackPress,
    onFullScreenModeUpdate,
    onPlay,
    onPause,
    onStop,
    onSkipNext,
    onSkipBack,
    onVolumeUpdate,
    onBrightnessUpdate,
    onMuteUpdate,
    onRepeatUpdate,
    onSpeedUpdate,
    onPlayListItemSelect,
    onScreenLockUpdate,
    onLoad,
    onError
  } = props;

  const [dimension, setDimension] = _react.default.useState({
    width: 0,
    height: 0
  });

  const [showControl, setShowControl] = _react.default.useState(false);

  const [showSpeedControl, setShowSpeedControl] = _react.default.useState(false);

  const [showTrackControl, setShowTrackControl] = _react.default.useState(false);

  const [showPlaylistControl, setShowPlaylistControl] = _react.default.useState(false);

  const [showMoreControl, setShowMoreControl] = _react.default.useState(false);

  const [loading, setLoading] = _react.default.useState(false);

  const [error, setError] = _react.default.useState(false);

  const [locked, setLocked] = _react.default.useState(false);

  const [disablePlaylistAndSkip, setDisablePlaylistAndSkip] = _react.default.useState(false);

  const [nexenSource, setNexenSource] = _react.default.useState(playerSource);

  const [nexenConfig, setNexenConfig] = _react.default.useState({
    loaderText: 'Loading...',
    errorText: 'Error...!',
    doubleTapTime: 300,
    controlTimeout: 5000,
    controlHideMode: 'touch',
    layoutMode: 'intermediate',
    posterResizeMode: 'cover',
    resizeMode: 'contain',
    volume: 80,
    brightness: 25,
    playbackSpeed: '1.0',
    muted: false,
    repeat: false,
    autoPlay: false,
    disableOnScreenPlayButton: false,
    disableBack: false,
    disableResizeMode: false,
    disableMore: false,
    disableSkip: false,
    disableStop: false,
    disableVolume: false,
    disableFullscreen: false,
    disablePlayList: false,
    disableSubtitle: false,
    ...playerConfig
  });

  const [fullScreen, setFullScreen] = _react.default.useState(false);

  const [paused, setPaused] = _react.default.useState(!(nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.autoPlay));

  const [trackInfo, setTrackInfo] = _react.default.useState({
    trackTime: 0,
    totalTrackTime: 0,
    cachedTrackTime: 0
  });

  const [playList, setPlayList] = _react.default.useState(playerPlayList);

  const [dropdownTextTracks, setDropdownTextTracks] = _react.default.useState();

  const [dropdownAudioTracks, setDropdownAudioTracks] = _react.default.useState();

  const durationTime = _react.default.useRef(0);

  const cachedTime = _react.default.useRef(0);

  const currentTime = _react.default.useRef(0);

  const isSeeking = _react.default.useRef(false);

  const isSliding = _react.default.useRef(false);

  const isSeekable = _react.default.useRef(false);

  const gestureEnabled = _react.default.useRef(false);

  const isStopped = _react.default.useRef(false);

  const isEnded = _react.default.useRef(false);

  const isVolumeSeekable = _react.default.useRef(true);

  const posterDisabled = _react.default.useRef(false);

  const showPoster = _react.default.useRef(true);

  const isFullscreen = _react.default.useRef(fullScreen);

  const appState = _react.default.useRef(_reactNative.AppState.currentState);

  const moreControlRef = _react.default.useRef(null);

  const speedControlRef = _react.default.useRef(null);

  const playlistControlRef = _react.default.useRef(null);

  const trackControlRef = _react.default.useRef(null);

  const videoRef = _react.default.useRef(null);

  const tipViewRef = _react.default.useRef(null);

  const headerControlRef = _react.default.useRef(null);

  const footerControlRef = _react.default.useRef(null);

  const headerOpacity = _react.default.useRef(new _reactNative.Animated.Value(0)).current;

  const headerTopMargin = _react.default.useRef(new _reactNative.Animated.Value(-60)).current;

  const footerOpacity = _react.default.useRef(new _reactNative.Animated.Value(0)).current;

  const footerBottomMargin = _react.default.useRef(new _reactNative.Animated.Value(-60)).current;

  const controlTimeoutRef = _react.default.useRef(null);

  _react.default.useImperativeHandle(ref, () => ({
    play: () => {
      setPaused(false);
    },
    pause: () => {
      setPaused(true);
    },
    stop: () => {
      handleStopPlayback();
    },
    skipNext: () => {
      _onSkipNext();
    },
    skipBack: () => {
      _onSkipBack();
    },
    setFullScreenMode: fullScreen => {
      setFullScreen(fullScreen);
      onFullScreenModeUpdate === null || onFullScreenModeUpdate === void 0 ? void 0 : onFullScreenModeUpdate(fullScreen, nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.optimize ? nexenConfig.index : playList === null || playList === void 0 ? void 0 : playList.currentIndex);
    }
  }));

  const nexenTheme = _react.default.useMemo(() => {
    return { ..._Theme.DefaultTheme,
      trackSeekBar: { ..._Theme.DefaultTheme.trackSeekBar,
        ...(theme === null || theme === void 0 ? void 0 : theme.trackSeekBar)
      },
      speedSeekBar: { ..._Theme.DefaultTheme.speedSeekBar,
        ...(theme === null || theme === void 0 ? void 0 : theme.speedSeekBar)
      },
      lineSeekBar: { ..._Theme.DefaultTheme.lineSeekBar,
        ...(theme === null || theme === void 0 ? void 0 : theme.lineSeekBar)
      },
      miniSeekBar: { ..._Theme.DefaultMiniSeekBarTheme,
        ...(theme === null || theme === void 0 ? void 0 : theme.miniSeekBar)
      },
      volumeSeekBar: { ..._Theme.DefaultTheme.volumeSeekBar,
        ...(theme === null || theme === void 0 ? void 0 : theme.volumeSeekBar)
      },
      brightnessSeekBar: { ..._Theme.DefaultTheme.brightnessSeekBar,
        ...(theme === null || theme === void 0 ? void 0 : theme.brightnessSeekBar)
      },
      lockButton: { ..._Theme.DefaultTheme.lockButton,
        ...(theme === null || theme === void 0 ? void 0 : theme.lockButton)
      },
      tagView: { ..._Theme.DefaultTheme.tagView,
        ...(theme === null || theme === void 0 ? void 0 : theme.tagView)
      },
      dropdownMenu: { ..._Theme.DefaultTheme.dropdownMenu,
        ...(theme === null || theme === void 0 ? void 0 : theme.dropdownMenu)
      },
      colors: { ..._Theme.DefaultTheme.colors,
        ...(theme === null || theme === void 0 ? void 0 : theme.colors)
      },
      sizes: { ..._Theme.DefaultSizesTheme,
        ...(theme === null || theme === void 0 ? void 0 : theme.sizes)
      },
      fonts: { ...(theme === null || theme === void 0 ? void 0 : theme.fonts)
      }
    };
  }, [theme]); // const ICON_SIZE_FACTOR = 0.8;


  const TAG_VIEW_ICON_SIZE = nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$tagView = nexenTheme.tagView) === null || _nexenTheme$tagView === void 0 ? void 0 : _nexenTheme$tagView.iconSize;
  const TAG_VIEW_ACTIVE_ICON_COLOR = (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$tagView2 = nexenTheme.tagView) === null || _nexenTheme$tagView2 === void 0 ? void 0 : _nexenTheme$tagView2.activeIconColor) || (0, _ColorUtil.getAlphaColor)(nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$colors = nexenTheme.colors) === null || _nexenTheme$colors === void 0 ? void 0 : _nexenTheme$colors.accentColor, 0.7);
  const TAG_VIEW_INACTIVE_ICON_COLOR = (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$tagView3 = nexenTheme.tagView) === null || _nexenTheme$tagView3 === void 0 ? void 0 : _nexenTheme$tagView3.inactiveIconColor) || (0, _ColorUtil.getAlphaColor)(nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$colors2 = nexenTheme.colors) === null || _nexenTheme$colors2 === void 0 ? void 0 : _nexenTheme$colors2.primaryColor, 0.5);
  const TIP_VIEW_ICON_SIZE = nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$tipView = nexenTheme.tipView) === null || _nexenTheme$tipView === void 0 ? void 0 : _nexenTheme$tipView.iconSize;
  const TIP_VIEW_TEXT_SIZE = nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$tipView2 = nexenTheme.tipView) === null || _nexenTheme$tipView2 === void 0 ? void 0 : _nexenTheme$tipView2.textSize;
  const TIP_VIEW_ICON_COLOR = ((_nexenTheme$tipView3 = nexenTheme.tipView) === null || _nexenTheme$tipView3 === void 0 ? void 0 : _nexenTheme$tipView3.iconColor) || ((_nexenTheme$colors3 = nexenTheme.colors) === null || _nexenTheme$colors3 === void 0 ? void 0 : _nexenTheme$colors3.secondaryIconColor);
  const TIP_VIEW_TEXT_COLOR = (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$tipView4 = nexenTheme.tipView) === null || _nexenTheme$tipView4 === void 0 ? void 0 : _nexenTheme$tipView4.textColor) || (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$colors4 = nexenTheme.colors) === null || _nexenTheme$colors4 === void 0 ? void 0 : _nexenTheme$colors4.secondaryTextColor);
  const CONTAINER_BORDER_RADIUS = nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$sizes = nexenTheme.sizes) === null || _nexenTheme$sizes === void 0 ? void 0 : _nexenTheme$sizes.modalCornerRadius;
  const CONTAINER_BACKGROUND_COLOR = (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$colors5 = nexenTheme.colors) === null || _nexenTheme$colors5 === void 0 ? void 0 : _nexenTheme$colors5.modalBackgroundColor) || (0, _ColorUtil.getAlphaColor)(nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$colors6 = nexenTheme.colors) === null || _nexenTheme$colors6 === void 0 ? void 0 : _nexenTheme$colors6.primaryColor, 0.7);
  const minValue = Math.min(Number(dimension.width), Number(dimension.height));
  const MORE_CONTROL_CONTAINER_WIDTH = fullScreen ? minValue * 0.55 + (insets === null || insets === void 0 ? void 0 : insets.right) : minValue * 0.7;
  const SPEED_CONTROL_CONTAINER_HEIGHT = fullScreen ? minValue * 0.2 + (insets === null || insets === void 0 ? void 0 : insets.bottom) : minValue * 0.3;
  const PLAYLIST_CONTROL_CONTAINER_HEIGHT = fullScreen ? minValue * 0.3 + (insets === null || insets === void 0 ? void 0 : insets.bottom) : minValue * 0.35;
  const TRACK_CONTROL_CONTAINER_HEIGHT = fullScreen ? minValue * 0.4 + (insets === null || insets === void 0 ? void 0 : insets.bottom) : minValue * 0.45;
  const LINE_SEEK_BAR_HEIGHT = 2;

  const rtlMultiplier = _react.default.useRef(1);

  const isRTL = _reactNative.I18nManager.isRTL;
  rtlMultiplier.current = isRTL ? -1 : 1;

  const tipViewTheme = _react.default.useMemo(() => {
    var _nexenTheme$fonts;

    return {
      textColor: TIP_VIEW_TEXT_COLOR,
      textSize: TIP_VIEW_TEXT_SIZE,
      font: nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$fonts = nexenTheme.fonts) === null || _nexenTheme$fonts === void 0 ? void 0 : _nexenTheme$fonts.secondaryFont
    };
  }, [nexenTheme]);

  const loaderTheme = _react.default.useMemo(() => {
    var _nexenTheme$fonts2;

    return {
      iconSize: 40,
      iconColor: TIP_VIEW_ICON_COLOR,
      textColor: TIP_VIEW_TEXT_COLOR,
      textSize: 16,
      font: nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$fonts2 = nexenTheme.fonts) === null || _nexenTheme$fonts2 === void 0 ? void 0 : _nexenTheme$fonts2.secondaryFont
    };
  }, [nexenTheme]);

  const lineSeekBarTheme = _react.default.useMemo(() => {
    var _nexenTheme$lineSeekB, _nexenTheme$colors7, _nexenTheme$lineSeekB2, _nexenTheme$colors8;

    return {
      lineHeight: LINE_SEEK_BAR_HEIGHT,
      lineColor: (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$lineSeekB = nexenTheme.lineSeekBar) === null || _nexenTheme$lineSeekB === void 0 ? void 0 : _nexenTheme$lineSeekB.lineColor) || (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$colors7 = nexenTheme.colors) === null || _nexenTheme$colors7 === void 0 ? void 0 : _nexenTheme$colors7.accentColor),
      lineUnderlayColor: (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$lineSeekB2 = nexenTheme.lineSeekBar) === null || _nexenTheme$lineSeekB2 === void 0 ? void 0 : _nexenTheme$lineSeekB2.lineUnderlayColor) || (0, _ColorUtil.getAlphaColor)(nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$colors8 = nexenTheme.colors) === null || _nexenTheme$colors8 === void 0 ? void 0 : _nexenTheme$colors8.secondaryColor, 0.3)
    };
  }, [nexenTheme]);

  const _onLayoutChange = async e => {
    const {
      width,
      height
    } = e.nativeEvent.layout;
    const {
      width: w,
      height: h
    } = dimension;

    if (w !== width || h !== height) {
      setDimension({
        width,
        height
      });
    }
  };

  const _onTapDetected = _react.default.useCallback((event, value) => {
    switch (event) {
      case _GestureView.TapEventType.SINGLE_TAP:
        if (showMoreControl) {
          hideMoreOptions();
          gestureEnabled.current = true;
          break;
        }

        if (showSpeedControl) {
          hidePlaybackSpeedControl();
          gestureEnabled.current = true;
          break;
        }

        if (showTrackControl) {
          hideSubtitleTrackControl();
          gestureEnabled.current = true;
          break;
        }

        if (showPlaylistControl) {
          hideVideoListControl();
          gestureEnabled.current = true;
          break;
        }

        if (showControl) {
          hideMainControl();
        } else {
          showMainControl();
        }

        break;

      case _GestureView.TapEventType.DOUBLE_TAP_LEFT:
      case _GestureView.TapEventType.DOUBLE_TAP_RIGHT:
        if (value) {
          var _videoRef$current;

          (_videoRef$current = videoRef.current) === null || _videoRef$current === void 0 ? void 0 : _videoRef$current.seek(value);
          setTrackInfo(prevState => {
            return { ...prevState,
              trackTime: value
            };
          });
        }

        break;

      case _GestureView.TapEventType.DOUBLE_TAP_MIDDLE:
        handleDoubleTapPlayPause();
        break;
    }
  }, [showControl, showSpeedControl, showTrackControl, showPlaylistControl, showMoreControl, paused]);

  const _onGestureMove = _react.default.useCallback((event, value) => {
    var _videoRef$current2, _headerControlRef$cur, _videoRef$current3, _headerControlRef$cur2;

    switch (event) {
      case _GestureView.GestureEventType.TRACK:
        (_videoRef$current2 = videoRef.current) === null || _videoRef$current2 === void 0 ? void 0 : _videoRef$current2.seek(value);
        setTrackInfo(prevState => {
          return { ...prevState,
            trackTime: value
          };
        });
        break;

      case _GestureView.GestureEventType.VOLUME:
        (_headerControlRef$cur = headerControlRef.current) === null || _headerControlRef$cur === void 0 ? void 0 : _headerControlRef$cur.updateIconTagView({
          volumeIcon: (0, _ComponentUtil.getVolumeIcon)(value, _GestureView.MAX_VOLUME, TAG_VIEW_ICON_SIZE, TIP_VIEW_ICON_COLOR)
        });
        (_videoRef$current3 = videoRef.current) === null || _videoRef$current3 === void 0 ? void 0 : _videoRef$current3.setNativeProps({
          volume: value / 100
        });
        break;

      case _GestureView.GestureEventType.BRIGHTNESS:
        (_headerControlRef$cur2 = headerControlRef.current) === null || _headerControlRef$cur2 === void 0 ? void 0 : _headerControlRef$cur2.updateIconTagView({
          brightnessIcon: (0, _ComponentUtil.getBrightnessIcon)(value, _GestureView.MAX_BRIGHTNESS, TAG_VIEW_ICON_SIZE, TIP_VIEW_ICON_COLOR)
        });
        NexenPlayerModule.setBrightness(value / 100);
        break;
    }
  }, []);

  const _onGestureEnd = _react.default.useCallback(async (event, value) => {
    var _videoRef$current4, _headerControlRef$cur3, _videoRef$current5, _headerControlRef$cur4;

    switch (event) {
      case _GestureView.GestureEventType.TRACK:
        (_videoRef$current4 = videoRef.current) === null || _videoRef$current4 === void 0 ? void 0 : _videoRef$current4.seek(value);
        setTrackInfo(prevState => {
          return { ...prevState,
            trackTime: value
          };
        });
        break;

      case _GestureView.GestureEventType.VOLUME:
        (_headerControlRef$cur3 = headerControlRef.current) === null || _headerControlRef$cur3 === void 0 ? void 0 : _headerControlRef$cur3.updateIconTagView({
          volumeIcon: (0, _ComponentUtil.getVolumeIcon)(value, _GestureView.MAX_VOLUME, TAG_VIEW_ICON_SIZE, TIP_VIEW_ICON_COLOR)
        });
        (_videoRef$current5 = videoRef.current) === null || _videoRef$current5 === void 0 ? void 0 : _videoRef$current5.setNativeProps({
          volume: value / 100
        });
        setNexenConfig(prevState => {
          return { ...prevState,
            volume: value
          };
        });
        onVolumeUpdate === null || onVolumeUpdate === void 0 ? void 0 : onVolumeUpdate(value);
        break;

      case _GestureView.GestureEventType.BRIGHTNESS:
        (_headerControlRef$cur4 = headerControlRef.current) === null || _headerControlRef$cur4 === void 0 ? void 0 : _headerControlRef$cur4.updateIconTagView({
          brightnessIcon: (0, _ComponentUtil.getBrightnessIcon)(value, _GestureView.MAX_BRIGHTNESS, TAG_VIEW_ICON_SIZE, TIP_VIEW_ICON_COLOR)
        });
        NexenPlayerModule.setBrightness(value / 100);
        setNexenConfig(prevState => {
          return { ...prevState,
            brightness: value
          };
        });
        onBrightnessUpdate === null || onBrightnessUpdate === void 0 ? void 0 : onBrightnessUpdate(value);
        break;
    }
  }, []);

  const showMainControl = () => {
    setShowControl(true);
  };

  const hideMainControl = () => {
    startControlHideAnimation(() => {
      setShowControl(false);
    });
  };

  const setControlTimeout = () => {
    controlTimeoutRef.current = setTimeout(() => {
      hideMainControl();
    }, nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.controlTimeout);
  };

  const clearControlTimeout = () => {
    if (controlTimeoutRef.current) {
      clearTimeout(controlTimeoutRef.current);
    }
  };

  const resetControlTimeout = () => {
    clearControlTimeout();
    setControlTimeout();
  };

  const showMoreOptions = () => {
    setShowMoreControl(true);
  };

  const hideMoreOptions = () => {
    var _moreControlRef$curre;

    (_moreControlRef$curre = moreControlRef.current) === null || _moreControlRef$curre === void 0 ? void 0 : _moreControlRef$curre.hide(() => {
      setShowMoreControl(false);
    });
  };

  const showPlaybackSpeedControl = () => {
    setShowSpeedControl(true);
  };

  const hidePlaybackSpeedControl = () => {
    var _speedControlRef$curr;

    (_speedControlRef$curr = speedControlRef.current) === null || _speedControlRef$curr === void 0 ? void 0 : _speedControlRef$curr.hide(() => {
      setShowSpeedControl(false);
    });
  };

  const showSubtitleTrackControl = () => {
    setShowTrackControl(true);
  };

  const hideSubtitleTrackControl = () => {
    var _trackControlRef$curr;

    (_trackControlRef$curr = trackControlRef.current) === null || _trackControlRef$curr === void 0 ? void 0 : _trackControlRef$curr.hide(() => {
      setShowTrackControl(false);
    });
  };

  const showVideoListControl = () => {
    setShowPlaylistControl(true);
  };

  const hideVideoListControl = () => {
    var _playlistControlRef$c;

    (_playlistControlRef$c = playlistControlRef.current) === null || _playlistControlRef$c === void 0 ? void 0 : _playlistControlRef$c.hide(() => {
      setShowPlaylistControl(false);
    });
  };

  const startControlShowAnimation = callback => {
    _reactNative.Animated.parallel([_reactNative.Animated.timing(headerOpacity, {
      toValue: 1,
      duration: ANIMATION_DURATION,
      useNativeDriver: USE_NATIVE_DRIVER
    }), _reactNative.Animated.timing(headerTopMargin, {
      toValue: 0,
      duration: ANIMATION_DURATION,
      useNativeDriver: USE_NATIVE_DRIVER
    }), _reactNative.Animated.timing(footerOpacity, {
      toValue: 1,
      duration: ANIMATION_DURATION,
      useNativeDriver: USE_NATIVE_DRIVER
    }), _reactNative.Animated.timing(footerBottomMargin, {
      toValue: 0,
      duration: ANIMATION_DURATION,
      useNativeDriver: USE_NATIVE_DRIVER
    })]).start(callback);
  };

  const startControlHideAnimation = callback => {
    _reactNative.Animated.parallel([_reactNative.Animated.timing(headerOpacity, {
      toValue: 0,
      duration: ANIMATION_DURATION,
      useNativeDriver: USE_NATIVE_DRIVER
    }), _reactNative.Animated.timing(headerTopMargin, {
      toValue: -60,
      duration: ANIMATION_DURATION,
      useNativeDriver: USE_NATIVE_DRIVER
    }), _reactNative.Animated.timing(footerOpacity, {
      toValue: 0,
      duration: ANIMATION_DURATION,
      useNativeDriver: USE_NATIVE_DRIVER
    }), _reactNative.Animated.timing(footerBottomMargin, {
      toValue: -60,
      duration: ANIMATION_DURATION,
      useNativeDriver: USE_NATIVE_DRIVER
    })]).start(callback);
  };

  _react.default.useEffect(() => {
    if (paused) {
      if (isStopped.current) {
        var _videoRef$current6;

        (_videoRef$current6 = videoRef.current) === null || _videoRef$current6 === void 0 ? void 0 : _videoRef$current6.seek(0, 0);
        onStop === null || onStop === void 0 ? void 0 : onStop(nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.optimize ? nexenConfig.index : playList === null || playList === void 0 ? void 0 : playList.currentIndex);
      }

      onPause === null || onPause === void 0 ? void 0 : onPause(nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.optimize ? nexenConfig.index : playList === null || playList === void 0 ? void 0 : playList.currentIndex);
    } else {
      isStopped.current = false;
      onPlay === null || onPlay === void 0 ? void 0 : onPlay(nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.optimize ? nexenConfig.index : playList === null || playList === void 0 ? void 0 : playList.currentIndex);
    }
  }, [paused]);

  _react.default.useEffect(() => {
    isFullscreen.current = fullScreen;

    if (showControl) {
      startControlShowAnimation();

      if ((nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.controlHideMode) == 'auto') {
        setControlTimeout();
      }
    } else {
      if ((nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.controlHideMode) == 'auto') {
        clearControlTimeout();
      }
    }

    if ((nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.layoutMode) === 'advanced') {
      var _headerControlRef$cur5;

      (_headerControlRef$cur5 = headerControlRef.current) === null || _headerControlRef$cur5 === void 0 ? void 0 : _headerControlRef$cur5.updateIconTagView({
        volumeIcon: (0, _ComponentUtil.getVolumeIcon)(nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.volume, _GestureView.MAX_VOLUME, TAG_VIEW_ICON_SIZE, TIP_VIEW_ICON_COLOR),
        brightnessIcon: (0, _ComponentUtil.getBrightnessIcon)(nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.brightness, _GestureView.MAX_BRIGHTNESS, TAG_VIEW_ICON_SIZE, TIP_VIEW_ICON_COLOR),
        repeatIcon: nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.repeat ? /*#__PURE__*/_react.default.createElement(_icons.IconRepeat, {
          size: TAG_VIEW_ICON_SIZE,
          color: TAG_VIEW_ACTIVE_ICON_COLOR
        }) : /*#__PURE__*/_react.default.createElement(_icons.IconRepeat, {
          size: TAG_VIEW_ICON_SIZE,
          color: TAG_VIEW_INACTIVE_ICON_COLOR
        }),
        speedIcon: (nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.playbackSpeed) !== '1.0' ? /*#__PURE__*/_react.default.createElement(_icons.IconZap, {
          size: TAG_VIEW_ICON_SIZE,
          color: TAG_VIEW_ACTIVE_ICON_COLOR
        }) : /*#__PURE__*/_react.default.createElement(_icons.IconZap, {
          size: TAG_VIEW_ICON_SIZE,
          color: TAG_VIEW_INACTIVE_ICON_COLOR
        })
      });
    }
  }, [showControl, fullScreen, locked, nexenConfig]);

  _react.default.useEffect(() => {
    if (showMoreControl) {
      var _moreControlRef$curre2;

      (_moreControlRef$curre2 = moreControlRef.current) === null || _moreControlRef$curre2 === void 0 ? void 0 : _moreControlRef$curre2.show();
      return;
    }

    if (showSpeedControl) {
      var _speedControlRef$curr2;

      (_speedControlRef$curr2 = speedControlRef.current) === null || _speedControlRef$curr2 === void 0 ? void 0 : _speedControlRef$curr2.show();
      return;
    }

    if (showTrackControl) {
      var _trackControlRef$curr2;

      (_trackControlRef$curr2 = trackControlRef.current) === null || _trackControlRef$curr2 === void 0 ? void 0 : _trackControlRef$curr2.show();
      return;
    }

    if (showPlaylistControl) {
      var _playlistControlRef$c2;

      (_playlistControlRef$c2 = playlistControlRef.current) === null || _playlistControlRef$c2 === void 0 ? void 0 : _playlistControlRef$c2.show();
      return;
    }
  }, [showMoreControl, showSpeedControl, showTrackControl, showPlaylistControl]);

  _react.default.useEffect(() => {
    currentTime.current = trackInfo.trackTime;
    cachedTime.current = trackInfo.cachedTrackTime;
    durationTime.current = trackInfo.totalTrackTime;
  }, [trackInfo]);

  _react.default.useEffect(() => {
    const currentIndex = RESIZE_MODE_VALUES.indexOf(nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.resizeMode);

    if (isSeekable.current) {
      var _tipViewRef$current;

      (_tipViewRef$current = tipViewRef.current) === null || _tipViewRef$current === void 0 ? void 0 : _tipViewRef$current.updateState({
        showTip: true,
        tipText: (0, _StringUtil.getAspectRatioTipText)(RESIZE_MODES[currentIndex]),
        autoHide: true
      });
    }
  }, [nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.resizeMode]);

  _react.default.useEffect(() => {
    const newConfig = { ...nexenConfig,
      ...playerConfig
    };
    NexenPlayerModule.setBrightness(newConfig.brightness / 100);
    setNexenConfig(newConfig);

    if (newConfig !== null && newConfig !== void 0 && newConfig.optimize) {
      if ((newConfig === null || newConfig === void 0 ? void 0 : newConfig.index) != (newConfig === null || newConfig === void 0 ? void 0 : newConfig.activeIndex)) {
        showPoster.current = true;
        setPaused(true);
        hideMainControl();
      } else {
        setPlayList(prevState => {
          return { ...prevState,
            currentIndex: newConfig === null || newConfig === void 0 ? void 0 : newConfig.activeIndex
          };
        });
      }
    }
  }, [playerConfig]);

  _react.default.useEffect(() => {
    const newSource = { ...nexenSource,
      ...playerSource
    };

    if (newSource.poster) {
      showPoster.current = true;
    } else {
      showPoster.current = false;
    }

    setNexenSource(newSource);
  }, [playerSource]);

  _react.default.useEffect(() => {
    if (!playerPlayList || !playerPlayList.items || playerPlayList.items.length === 0) {
      setDisablePlaylistAndSkip(true);
    } else {
      setDisablePlaylistAndSkip(false);
    }

    setPlayList(prevState => {
      return { ...prevState,
        ...playerPlayList
      };
    });
  }, [playerPlayList]);

  _react.default.useEffect(() => {
    const backHandler = _reactNative.BackHandler.addEventListener('hardwareBackPress', _onBackPress);

    const subscription = _reactNative.AppState.addEventListener('change', nextAppState => {
      if (appState.current.match(/inactive|background/) && nextAppState === 'active') {
        if (isFullscreen.current) {
          NexenPlayerModule.hideSystemBar();
        }
      }

      appState.current = nextAppState;
    });

    return () => {
      backHandler.remove();
      subscription.remove();

      if (controlTimeoutRef.current) {
        clearTimeout(controlTimeoutRef.current);
      }
    };
  }, []);

  const _onBackPress = _react.default.useCallback(() => {
    if (isFullscreen.current) {
      setFullScreen(false);
      NexenPlayerModule.showSystemBar();
      onFullScreenModeUpdate === null || onFullScreenModeUpdate === void 0 ? void 0 : onFullScreenModeUpdate(false, nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.optimize ? nexenConfig.index : playList === null || playList === void 0 ? void 0 : playList.currentIndex);
    } else {
      onBackPress === null || onBackPress === void 0 ? void 0 : onBackPress();
    }

    return true;
  }, []);

  const _onAspectRatioPress = _react.default.useCallback(() => {
    handleResizeMode(nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.resizeMode);
  }, [nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.resizeMode]);

  const _onMorePress = _react.default.useCallback(() => {
    showMoreOptions();
    hideMainControl();
    gestureEnabled.current = false;
  }, []);

  const _onMoreItemPress = _react.default.useCallback(item => {
    switch (item.id) {
      case 'lock':
        hideMoreOptions();
        handleLockScreen();
        isSeekable.current = false;
        gestureEnabled.current = false;
        break;

      case 'speed':
        hideMoreOptions();
        showPlaybackSpeedControl();
        gestureEnabled.current = false;
        break;

      case 'repeat':
        hideMoreOptions();
        handleRepeatVideo(!(nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.repeat));
        gestureEnabled.current = true;
        break;
    }
  }, [nexenConfig]);

  const _onSpeedUpdate = _react.default.useCallback(value => {
    var _tipViewRef$current2;

    const newSpeed = value;
    (_tipViewRef$current2 = tipViewRef.current) === null || _tipViewRef$current2 === void 0 ? void 0 : _tipViewRef$current2.updateState({
      showTip: true,
      tipText: `${newSpeed}x Speed`,
      autoHide: true,
      withIcon: true,
      icon: /*#__PURE__*/_react.default.createElement(_icons.IconZap, {
        size: TIP_VIEW_ICON_SIZE,
        color: TIP_VIEW_ICON_COLOR
      })
    });
    setNexenConfig(prevState => {
      return { ...prevState,
        playbackSpeed: newSpeed
      };
    });
    onSpeedUpdate === null || onSpeedUpdate === void 0 ? void 0 : onSpeedUpdate(newSpeed);
  }, []);

  const _onTextTrackSelect = _react.default.useCallback(selectedTextTrack => {
    setNexenSource(prevState => {
      return { ...prevState,
        selectedTextTrack
      };
    });
  }, []);

  const _onAudioTrackSelect = _react.default.useCallback(selectedAudioTrack => {
    setNexenSource(prevState => {
      return { ...prevState,
        selectedAudioTrack
      };
    });
  }, []);

  const handleDoubleTapPlayPause = () => {
    if (paused) {
      var _tipViewRef$current3;

      setPaused(false);
      (_tipViewRef$current3 = tipViewRef.current) === null || _tipViewRef$current3 === void 0 ? void 0 : _tipViewRef$current3.updateState({
        showTip: true,
        tipText: 'Playing',
        autoHide: true,
        withIcon: true,
        icon: /*#__PURE__*/_react.default.createElement(_icons.IconPaly, {
          size: TIP_VIEW_ICON_SIZE,
          color: TIP_VIEW_ICON_COLOR
        })
      });
    } else {
      var _tipViewRef$current4;

      setPaused(true);
      (_tipViewRef$current4 = tipViewRef.current) === null || _tipViewRef$current4 === void 0 ? void 0 : _tipViewRef$current4.updateState({
        showTip: true,
        tipText: 'Paused',
        autoHide: true,
        withIcon: true,
        icon: /*#__PURE__*/_react.default.createElement(_icons.IconPause, {
          size: TIP_VIEW_ICON_SIZE,
          color: TIP_VIEW_ICON_COLOR
        })
      });
    }
  };
  /* FooterControl Callback */


  const _onPlayPress = () => {
    setPaused(false);
  };

  const _onCcPress = () => {
    hideMainControl();
    showSubtitleTrackControl();
    gestureEnabled.current = false;
  };

  const _onStopPress = () => {
    handleStopPlayback();
  };

  const handleStopPlayback = () => {
    isStopped.current = true;

    if (paused) {
      var _videoRef$current7;

      (_videoRef$current7 = videoRef.current) === null || _videoRef$current7 === void 0 ? void 0 : _videoRef$current7.seek(0, 0);
      onStop === null || onStop === void 0 ? void 0 : onStop(nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.optimize ? nexenConfig.index : playList === null || playList === void 0 ? void 0 : playList.currentIndex);
    } else {
      if (isEnded.current && nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.repeat) {
        var _videoRef$current8;

        setPaused(false);
        (_videoRef$current8 = videoRef.current) === null || _videoRef$current8 === void 0 ? void 0 : _videoRef$current8.seek(0, 0);
        onStop === null || onStop === void 0 ? void 0 : onStop(nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.optimize ? nexenConfig.index : playList === null || playList === void 0 ? void 0 : playList.currentIndex);
      } else {
        setPaused(true);
      }
    }
  };

  const handleRepeatVideo = repeat => {
    var _tipViewRef$current5;

    (_tipViewRef$current5 = tipViewRef.current) === null || _tipViewRef$current5 === void 0 ? void 0 : _tipViewRef$current5.updateState({
      showTip: true,
      tipText: repeat ? 'Repeat On' : 'Repeat Off',
      autoHide: true,
      withIcon: true,
      icon: /*#__PURE__*/_react.default.createElement(_icons.IconRepeat, {
        size: TIP_VIEW_ICON_SIZE,
        color: TIP_VIEW_ICON_COLOR
      })
    });
    setNexenConfig(prevState => {
      return { ...prevState,
        repeat: repeat
      };
    });
    onRepeatUpdate === null || onRepeatUpdate === void 0 ? void 0 : onRepeatUpdate(repeat);
  };

  const handleResizeMode = resizeMode => {
    const currentIndex = RESIZE_MODE_VALUES.indexOf(resizeMode);

    if (currentIndex < RESIZE_MODE_VALUES.length - 1) {
      setNexenConfig(prevState => {
        return { ...prevState,
          resizeMode: RESIZE_MODE_VALUES[currentIndex + 1]
        };
      });
    } else {
      setNexenConfig(prevState => {
        return { ...prevState,
          resizeMode: RESIZE_MODE_VALUES[0]
        };
      });
    }
  };

  const handleLockScreen = () => {
    var _tipViewRef$current6;

    (_tipViewRef$current6 = tipViewRef.current) === null || _tipViewRef$current6 === void 0 ? void 0 : _tipViewRef$current6.updateState({
      showTip: true,
      tipText: 'Locked',
      autoHide: true,
      withIcon: true,
      icon: /*#__PURE__*/_react.default.createElement(_icons.IconLock, {
        size: TIP_VIEW_ICON_SIZE,
        color: TIP_VIEW_ICON_COLOR
      })
    });
    setLocked(true);
    onScreenLockUpdate === null || onScreenLockUpdate === void 0 ? void 0 : onScreenLockUpdate(true);
  };

  const handleTextTracks = textTracks => {
    const selectedTrack = textTracks === null || textTracks === void 0 ? void 0 : textTracks.find(x => {
      return x.selected;
    });
    setDropdownTextTracks(textTracks);

    if (selectedTrack !== null && selectedTrack !== void 0 && selectedTrack.language) {
      setNexenSource(prevState => {
        return { ...prevState,
          selectedTextTrack: {
            type: 'language',
            value: selectedTrack === null || selectedTrack === void 0 ? void 0 : selectedTrack.language
          }
        };
      });
    }
  };

  const handleAudioTracks = audioTracks => {
    const selectedTrack = audioTracks === null || audioTracks === void 0 ? void 0 : audioTracks.find(x => {
      return x.selected;
    });
    setDropdownAudioTracks(audioTracks);

    if (selectedTrack !== null && selectedTrack !== void 0 && selectedTrack.language) {
      setNexenSource(prevState => {
        return { ...prevState,
          selectedAudioTrack: {
            type: 'language',
            value: selectedTrack === null || selectedTrack === void 0 ? void 0 : selectedTrack.language
          }
        };
      });
    }
  };

  const _onRewind = () => {
    var _videoRef$current9;

    const time = trackInfo.trackTime - FORWARD_OR_REWIND_DURATION;
    (_videoRef$current9 = videoRef.current) === null || _videoRef$current9 === void 0 ? void 0 : _videoRef$current9.seek(time);
    setTrackInfo(prevState => {
      return { ...prevState,
        trackTime: time
      };
    });
  };

  const _onFastForward = () => {
    var _videoRef$current10;

    const time = trackInfo.trackTime + FORWARD_OR_REWIND_DURATION;
    (_videoRef$current10 = videoRef.current) === null || _videoRef$current10 === void 0 ? void 0 : _videoRef$current10.seek(time);
    setTrackInfo(prevState => {
      return { ...prevState,
        trackTime: time
      };
    });
  };

  const _onSkipNext = () => {
    if (playList) {
      var _playList$items;

      if (playList.currentIndex < ((_playList$items = playList.items) === null || _playList$items === void 0 ? void 0 : _playList$items.length) - 1) {
        const index = playList.currentIndex + 1;
        setPlayList(prevState => {
          return { ...prevState,
            currentIndex: index
          };
        });
        onSkipNext === null || onSkipNext === void 0 ? void 0 : onSkipNext(index);
      }
    }
  };

  const _onSkipBack = () => {
    if (playList) {
      if (playList.currentIndex > 0) {
        const index = playList.currentIndex - 1;
        setPlayList(prevState => {
          return { ...prevState,
            currentIndex: index
          };
        });
        onSkipBack === null || onSkipBack === void 0 ? void 0 : onSkipBack(index);
      }
    }
  };

  const _onVideoListPress = () => {
    hideMainControl();
    showVideoListControl();
    gestureEnabled.current = false;
  };

  const _onPlaylistItemPress = index => {
    setPlayList(prevState => {
      return { ...prevState,
        currentIndex: index
      };
    });
    onPlayListItemSelect === null || onPlayListItemSelect === void 0 ? void 0 : onPlayListItemSelect(index);
  };

  const _onTogglePlayPause = () => {
    setPaused(prevState => !prevState);
  };

  const _onToggleFullScreen = () => {
    if (fullScreen) {
      NexenPlayerModule.showSystemBar();
    } else {
      NexenPlayerModule.hideSystemBar();
    }

    onFullScreenModeUpdate === null || onFullScreenModeUpdate === void 0 ? void 0 : onFullScreenModeUpdate(!fullScreen, nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.optimize ? nexenConfig.index : playList === null || playList === void 0 ? void 0 : playList.currentIndex);
    setFullScreen(prevState => !prevState);
  };

  const _onToggleVolume = () => {
    handleMuteVideo(!(nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.muted));
  };

  const handleMuteVideo = mute => {
    var _tipViewRef$current7;

    (_tipViewRef$current7 = tipViewRef.current) === null || _tipViewRef$current7 === void 0 ? void 0 : _tipViewRef$current7.updateState({
      showTip: true,
      tipText: mute ? 'Sound Off' : 'Sound On',
      autoHide: true
    });
    isVolumeSeekable.current = !mute;
    onMuteUpdate === null || onMuteUpdate === void 0 ? void 0 : onMuteUpdate(mute);
    setNexenConfig(prevState => {
      return { ...prevState,
        muted: mute
      };
    });
  };
  /* Slide Button Callback */


  const _onSlideStart = _react.default.useCallback(() => {
    isSliding.current = true;
  }, []);

  const _onSlideEnd = _react.default.useCallback(() => {
    isSliding.current = false;
  }, []);

  const _onReachedToStart = _react.default.useCallback(() => {}, []);

  const _onReachedToEnd = _react.default.useCallback(() => {
    var _tipViewRef$current8;

    setLocked(false);
    isSeekable.current = true;
    gestureEnabled.current = true;
    (_tipViewRef$current8 = tipViewRef.current) === null || _tipViewRef$current8 === void 0 ? void 0 : _tipViewRef$current8.updateState({
      showTip: true,
      tipText: 'Unlocked',
      autoHide: true,
      withIcon: true,
      icon: /*#__PURE__*/_react.default.createElement(_icons.IconUnlock, {
        size: TIP_VIEW_ICON_SIZE,
        color: TIP_VIEW_ICON_COLOR
      })
    });
  }, []);
  /* SeekBar Callback */


  const _onSeekStart = _react.default.useCallback((value, totalValue) => {
    var _tipViewRef$current9;

    isSeeking.current = true;
    (_tipViewRef$current9 = tipViewRef.current) === null || _tipViewRef$current9 === void 0 ? void 0 : _tipViewRef$current9.updateState({
      showTip: true,
      tipText: (0, _StringUtil.getTimeTipText)(value, totalValue),
      autoHide: false
    });
  }, []);

  const _onSeekUpdate = _react.default.useCallback((value, totalValue) => {
    if (isSeeking.current) {
      var _tipViewRef$current10;

      (_tipViewRef$current10 = tipViewRef.current) === null || _tipViewRef$current10 === void 0 ? void 0 : _tipViewRef$current10.updateState({
        tipText: (0, _StringUtil.getTimeTipText)(value, totalValue)
      });
    }
  }, []);

  const _onSeekEnd = _react.default.useCallback(value => {
    var _videoRef$current11, _tipViewRef$current11;

    isSeeking.current = false;
    (_videoRef$current11 = videoRef.current) === null || _videoRef$current11 === void 0 ? void 0 : _videoRef$current11.seek(value);
    setTrackInfo(prevState => {
      return { ...prevState,
        trackTime: value
      };
    });
    (_tipViewRef$current11 = tipViewRef.current) === null || _tipViewRef$current11 === void 0 ? void 0 : _tipViewRef$current11.updateState({
      showTip: false,
      autoHide: true
    });
  }, []);
  /* Volume SeekBar Callback */


  const _onVolumeSeekStart = _react.default.useCallback((value, totalValue) => {
    var _videoRef$current12, _tipViewRef$current12;

    (_videoRef$current12 = videoRef.current) === null || _videoRef$current12 === void 0 ? void 0 : _videoRef$current12.setNativeProps({
      volume: value / 100
    });
    (_tipViewRef$current12 = tipViewRef.current) === null || _tipViewRef$current12 === void 0 ? void 0 : _tipViewRef$current12.updateState({
      showTip: true,
      tipText: `Volume : ${value}%`,
      autoHide: false
    });
    onVolumeUpdate === null || onVolumeUpdate === void 0 ? void 0 : onVolumeUpdate(value);
  }, []);

  const _onVolumeSeekUpdate = _react.default.useCallback((value, totalValue) => {
    var _videoRef$current13, _tipViewRef$current13;

    (_videoRef$current13 = videoRef.current) === null || _videoRef$current13 === void 0 ? void 0 : _videoRef$current13.setNativeProps({
      volume: value / 100
    });
    (_tipViewRef$current13 = tipViewRef.current) === null || _tipViewRef$current13 === void 0 ? void 0 : _tipViewRef$current13.updateState({
      showTip: true,
      tipText: `Volume : ${value}%`,
      autoHide: false
    });
    onVolumeUpdate === null || onVolumeUpdate === void 0 ? void 0 : onVolumeUpdate(value);
  }, []);

  const _onVolumeSeekEnd = _react.default.useCallback(value => {
    var _videoRef$current14, _tipViewRef$current14;

    setNexenConfig(prevState => {
      return { ...prevState,
        volume: value
      };
    });
    (_videoRef$current14 = videoRef.current) === null || _videoRef$current14 === void 0 ? void 0 : _videoRef$current14.setNativeProps({
      volume: value / 100
    });
    (_tipViewRef$current14 = tipViewRef.current) === null || _tipViewRef$current14 === void 0 ? void 0 : _tipViewRef$current14.updateState({
      showTip: false,
      autoHide: true
    });
    onVolumeUpdate === null || onVolumeUpdate === void 0 ? void 0 : onVolumeUpdate(value);
  }, []);
  /* Video Callback */


  const _onLoadStart = _react.default.useCallback(() => {
    setLoading(true);
    showPoster.current = true;
  }, []);

  const _onLoad = _react.default.useCallback(data => {
    setLoading(false);
    setError(false);
    onLoad === null || onLoad === void 0 ? void 0 : onLoad(nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.optimize ? nexenConfig.index : playList === null || playList === void 0 ? void 0 : playList.currentIndex);

    if (nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.autoPlay) {
      setPaused(false);
    }

    setTrackInfo(prevState => {
      return { ...prevState,
        trackTime: data.currentTime,
        totalTrackTime: data.duration
      };
    });
    handleTextTracks(data.textTracks);
    handleAudioTracks(data.audioTracks);
    isSeekable.current = true;
    gestureEnabled.current = true;
    isStopped.current = false;
  }, []);

  const _onProgress = _react.default.useCallback(data => {
    if (showPoster) {
      showPoster.current = false;
    }

    if (!isSeeking.current) {
      setTrackInfo({
        trackTime: data.currentTime,
        cachedTrackTime: data.playableDuration,
        totalTrackTime: data.seekableDuration
      });
    }
  }, [showPoster]);

  const _onSeek = _react.default.useCallback(data => {
    if (isStopped.current && data.seekTime == 0 && data.currentTime == 0) {
      setTrackInfo(prevState => {
        return { ...prevState,
          trackTime: 0,
          cachedTrackTime: 0
        };
      });
      isEnded.current = false;
      isStopped.current = false;
    }
  }, []);

  const _onEnd = _react.default.useCallback(() => {
    isEnded.current = true;
    handleStopPlayback();
  }, [paused, nexenConfig]);

  const _onError = _react.default.useCallback(error => {
    setError(true);
    onError === null || onError === void 0 ? void 0 : onError(error.error.errorString);
  }, []);

  const newSource = playList !== null && playList !== void 0 && playList.items ? (playList === null || playList === void 0 ? void 0 : playList.items.length) !== 0 ? playList === null || playList === void 0 ? void 0 : playList.items[playList.currentIndex].itemSource : nexenSource : nexenSource;

  if (newSource.poster) {
    posterDisabled.current = false;
  } else {
    posterDisabled.current = true;
  }

  const newStyle = fullScreen ? {
    position: 'absolute',
    width: '100%',
    height: '100%',
    top: 0,
    left: 0,
    zIndex: 9999
  } : {
    position: 'relative'
  };
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.playerContainer, style, newStyle],
    onLayout: _onLayoutChange
  }, nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.optimize ? (nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.index) === (nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.activeIndex) ? /*#__PURE__*/_react.default.createElement(_reactNativeVideo.default, {
    ref: videoRef,
    style: styles.player,
    source: newSource.source,
    textTracks: newSource.textTracks,
    selectedTextTrack: newSource.selectedTextTrack,
    selectedAudioTrack: newSource.selectedAudioTrack,
    paused: paused,
    resizeMode: nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.resizeMode,
    muted: nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.muted,
    volume: (nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.volume) / 100,
    repeat: nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.repeat,
    rate: Number(nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.playbackSpeed),
    progressUpdateInterval: 1000,
    onLoadStart: _onLoadStart,
    onLoad: _onLoad,
    onProgress: _onProgress,
    onSeek: _onSeek,
    onEnd: _onEnd,
    onError: _onError
  }) : null : /*#__PURE__*/_react.default.createElement(_reactNativeVideo.default, {
    ref: videoRef,
    style: styles.player,
    source: newSource.source,
    textTracks: newSource.textTracks,
    selectedTextTrack: newSource.selectedTextTrack,
    selectedAudioTrack: newSource.selectedAudioTrack,
    paused: paused,
    resizeMode: nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.resizeMode,
    muted: nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.muted,
    volume: (nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.volume) / 100,
    repeat: nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.repeat,
    rate: Number(nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.playbackSpeed),
    progressUpdateInterval: 1000,
    onLoadStart: _onLoadStart,
    onLoad: _onLoad,
    onProgress: _onProgress,
    onSeek: _onSeek,
    onEnd: _onEnd,
    onError: _onError
  }), !posterDisabled.current && showPoster.current && !error && /*#__PURE__*/_react.default.createElement(_PosterView.default, {
    posterSource: newSource.poster,
    posterResizeMode: nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.posterResizeMode
  }), /*#__PURE__*/_react.default.createElement(_GestureView.default, {
    fullScreen: fullScreen,
    locked: locked,
    error: error,
    isSeeking: isSeeking,
    isSliding: isSliding,
    isSeekable: isSeekable,
    gestureEnabled: gestureEnabled,
    durationTime: durationTime,
    currentTime: currentTime,
    dimension: dimension,
    playerConfig: nexenConfig,
    nexenTheme: nexenTheme,
    onTapDetected: _onTapDetected,
    onGestureMove: _onGestureMove,
    onGestureEnd: _onGestureEnd
  }), /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, showControl && /*#__PURE__*/_react.default.createElement(_HeaderControl.default, {
    ref: headerControlRef,
    title: newSource.title,
    opacity: headerOpacity,
    marginTop: headerTopMargin,
    fullScreen: fullScreen,
    locked: locked,
    insets: insets,
    playerConfig: nexenConfig,
    nexenTheme: nexenTheme,
    onBackPress: _onBackPress,
    onAspectRatioPress: _onAspectRatioPress,
    onMorePress: _onMorePress
  }), showControl && /*#__PURE__*/_react.default.createElement(_FooterControl.default, {
    ref: footerControlRef,
    opacity: footerOpacity,
    marginBottom: footerBottomMargin,
    fullScreen: fullScreen,
    locked: locked,
    insets: insets,
    playerConfig: nexenConfig,
    nexenTheme: nexenTheme,
    paused: paused,
    isSeekable: isSeekable,
    isVolumeSeekable: isVolumeSeekable,
    trackTime: trackInfo.trackTime,
    cachedTrackTime: trackInfo.cachedTrackTime,
    totalTrackTime: trackInfo.totalTrackTime,
    totalVolume: _GestureView.MAX_VOLUME,
    disablePlaylistAndSkip: disablePlaylistAndSkip,
    onStopPress: _onStopPress,
    onPlayPress: _onTogglePlayPause,
    onFullScreenPress: _onToggleFullScreen,
    onVolumePress: _onToggleVolume,
    onCcPress: _onCcPress,
    onVideoListPress: _onVideoListPress,
    onAspectRatioPress: _onAspectRatioPress,
    onRewind: _onRewind,
    onFastForward: _onFastForward,
    onSeekStart: _onSeekStart,
    onSkipNext: _onSkipNext,
    onSkipBack: _onSkipBack,
    onSeekUpdate: _onSeekUpdate,
    onSeekEnd: _onSeekEnd,
    onVolumeSeekStart: _onVolumeSeekStart,
    onVolumeSeekUpdate: _onVolumeSeekUpdate,
    onVolumeSeekEnd: _onVolumeSeekEnd,
    onSlideStart: _onSlideStart,
    onSlideEnd: _onSlideEnd,
    onReachedToStart: _onReachedToStart,
    onReachedToEnd: _onReachedToEnd
  }), !showControl && !showMoreControl && !showSpeedControl && !showTrackControl && /*#__PURE__*/_react.default.createElement(_LineSeekBar.default, {
    trackTime: trackInfo.trackTime,
    totalTrackTime: trackInfo.totalTrackTime,
    layoutWidth: dimension.width,
    theme: lineSeekBarTheme
  }), showMoreControl && /*#__PURE__*/_react.default.createElement(_MoreControl.default, {
    ref: moreControlRef,
    animateFrom: 'RIGHT',
    distance: MORE_CONTROL_CONTAINER_WIDTH,
    style: {
      width: MORE_CONTROL_CONTAINER_WIDTH,
      backgroundColor: CONTAINER_BACKGROUND_COLOR,
      borderTopLeftRadius: CONTAINER_BORDER_RADIUS,
      borderBottomLeftRadius: CONTAINER_BORDER_RADIUS
    },
    fullScreen: fullScreen,
    insets: insets,
    nexenTheme: nexenTheme,
    onItemPress: _onMoreItemPress
  }), showSpeedControl && /*#__PURE__*/_react.default.createElement(_SpeedControl.default, {
    ref: speedControlRef,
    animateFrom: 'BOTTOM',
    distance: SPEED_CONTROL_CONTAINER_HEIGHT,
    style: {
      height: SPEED_CONTROL_CONTAINER_HEIGHT,
      backgroundColor: CONTAINER_BACKGROUND_COLOR,
      borderTopLeftRadius: CONTAINER_BORDER_RADIUS,
      borderTopRightRadius: CONTAINER_BORDER_RADIUS
    },
    fullScreen: fullScreen,
    insets: insets,
    currentSpeed: nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.playbackSpeed,
    nexenTheme: nexenTheme,
    onSpeedChange: _onSpeedUpdate
  }), showTrackControl && /*#__PURE__*/_react.default.createElement(_TrackControl.default, {
    ref: trackControlRef,
    animateFrom: 'BOTTOM',
    distance: TRACK_CONTROL_CONTAINER_HEIGHT,
    style: {
      height: TRACK_CONTROL_CONTAINER_HEIGHT,
      backgroundColor: CONTAINER_BACKGROUND_COLOR,
      borderTopLeftRadius: CONTAINER_BORDER_RADIUS,
      borderTopRightRadius: CONTAINER_BORDER_RADIUS
    },
    textTracks: dropdownTextTracks,
    selectedTextTrack: nexenSource.selectedTextTrack,
    onTextTrackSelect: _onTextTrackSelect,
    audioTracks: dropdownAudioTracks,
    selectedAudioTrack: nexenSource.selectedAudioTrack,
    onAudioTrackSelect: _onAudioTrackSelect,
    fullScreen: fullScreen,
    insets: insets,
    nexenTheme: nexenTheme
  }), showPlaylistControl && /*#__PURE__*/_react.default.createElement(_PlaylistControl.default, {
    ref: playlistControlRef,
    animateFrom: 'BOTTOM',
    distance: PLAYLIST_CONTROL_CONTAINER_HEIGHT,
    style: {
      height: PLAYLIST_CONTROL_CONTAINER_HEIGHT,
      backgroundColor: CONTAINER_BACKGROUND_COLOR,
      borderTopLeftRadius: CONTAINER_BORDER_RADIUS,
      borderTopRightRadius: CONTAINER_BORDER_RADIUS
    },
    playlist: playList === null || playList === void 0 ? void 0 : playList.items,
    playlistIndex: playList === null || playList === void 0 ? void 0 : playList.currentIndex,
    fullScreen: fullScreen,
    nexenTheme: nexenTheme,
    onPlayListItemPress: _onPlaylistItemPress
  }), paused && !showControl && !showMoreControl && !showSpeedControl && !showTrackControl && !showPlaylistControl && !locked && !loading && !error && !(nexenConfig !== null && nexenConfig !== void 0 && nexenConfig.disableOnScreenPlayButton) && /*#__PURE__*/_react.default.createElement(_PlayButton.default, {
    dimension: dimension,
    onPlayPress: _onPlayPress
  }), !error && loading && /*#__PURE__*/_react.default.createElement(_Loader.default, {
    style: {
      backgroundColor: CONTAINER_BACKGROUND_COLOR,
      borderRadius: CONTAINER_BORDER_RADIUS
    },
    theme: loaderTheme,
    loaderText: nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.loaderText
  }), (nexenConfig === null || nexenConfig === void 0 ? void 0 : nexenConfig.layoutMode) !== 'basic' && /*#__PURE__*/_react.default.createElement(_TipView.default, {
    ref: tipViewRef,
    style: {
      backgroundColor: CONTAINER_BACKGROUND_COLOR,
      borderRadius: CONTAINER_BORDER_RADIUS
    },
    theme: tipViewTheme
  })));
});

var _default = NexenPlayer;
exports.default = _default;
NexenPlayer.defaultProps = {
  playList: {
    items: [],
    currentIndex: 0
  },
  insets: {
    left: 0,
    top: 0,
    right: 0,
    bottom: 0
  }
};

const styles = _reactNative.StyleSheet.create({
  playerContainer: {
    position: 'relative',
    width: '100%',
    height: '100%',
    overflow: 'hidden',
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: '#0a0a0a'
  },
  player: {
    width: '100%',
    height: '100%',
    backgroundColor: '#0a0a0a'
  }
});
//# sourceMappingURL=NexenPlayer.js.map