import React from 'react';
import { StyleSheet, View } from 'react-native';
import DropDown from './DropDown';
import GradientView from './GradientView';
import ModalView from './ModalView';
import { withAnimation } from '../hoc/withAnimation';
import { getAlphaColor } from '../utils/ColorUtil';

const TrackControl = props => {
  const {
    style,
    fullScreen,
    nexenTheme,
    insets,
    textTracks,
    selectedTextTrack,
    audioTracks,
    selectedAudioTrack,
    onTextTrackSelect,
    onAudioTrackSelect
  } = props;
  const styleHeight = StyleSheet.flatten(style).height || 100;
  const dropdownHeight = Number(styleHeight) - 10 * 2 - 40;
  const CONTAINER_HORIZONTAL_PADDING = fullScreen ? ((insets === null || insets === void 0 ? void 0 : insets.left) + (insets === null || insets === void 0 ? void 0 : insets.right)) / 2 > 0 ? ((insets === null || insets === void 0 ? void 0 : insets.left) + (insets === null || insets === void 0 ? void 0 : insets.right)) / 2 : 8 : 8;
  const [textItems, setTextItems] = React.useState();
  const [selectedTextItem, setSelectedTextItem] = React.useState();
  const [audioItems, setAudioItems] = React.useState();
  const [selectedAudioItem, setSelectedAudioItem] = React.useState();
  const dropDownTheme = React.useMemo(() => {
    var _nexenTheme$fonts, _nexenTheme$dropdownM, _nexenTheme$colors, _nexenTheme$dropdownM2, _nexenTheme$colors2, _nexenTheme$dropdownM3, _nexenTheme$colors3, _nexenTheme$dropdownM4, _nexenTheme$colors4, _nexenTheme$dropdownM5, _nexenTheme$colors5, _nexenTheme$dropdownM6, _nexenTheme$colors6, _nexenTheme$dropdownM7, _nexenTheme$colors7, _nexenTheme$dropdownM8, _nexenTheme$sizes, _nexenTheme$dropdownM9, _nexenTheme$sizes2, _nexenTheme$dropdownM10, _nexenTheme$sizes3, _nexenTheme$dropdownM11;

    return {
      font: nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$fonts = nexenTheme.fonts) === null || _nexenTheme$fonts === void 0 ? void 0 : _nexenTheme$fonts.secondaryFont,
      backgroundColor: (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$dropdownM = nexenTheme.dropdownMenu) === null || _nexenTheme$dropdownM === void 0 ? void 0 : _nexenTheme$dropdownM.backgroundColor) || getAlphaColor(nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$colors = nexenTheme.colors) === null || _nexenTheme$colors === void 0 ? void 0 : _nexenTheme$colors.secondaryColor, 0.1),
      headerBackgroundColor: (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$dropdownM2 = nexenTheme.dropdownMenu) === null || _nexenTheme$dropdownM2 === void 0 ? void 0 : _nexenTheme$dropdownM2.headerBackgroundColor) || getAlphaColor(nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$colors2 = nexenTheme.colors) === null || _nexenTheme$colors2 === void 0 ? void 0 : _nexenTheme$colors2.primaryColor, 0.7),
      itemBackgroundColor: (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$dropdownM3 = nexenTheme.dropdownMenu) === null || _nexenTheme$dropdownM3 === void 0 ? void 0 : _nexenTheme$dropdownM3.itemBackgroundColor) || getAlphaColor(nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$colors3 = nexenTheme.colors) === null || _nexenTheme$colors3 === void 0 ? void 0 : _nexenTheme$colors3.primaryColor, 0.3),
      textColor: (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$dropdownM4 = nexenTheme.dropdownMenu) === null || _nexenTheme$dropdownM4 === void 0 ? void 0 : _nexenTheme$dropdownM4.textColor) || (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$colors4 = nexenTheme.colors) === null || _nexenTheme$colors4 === void 0 ? void 0 : _nexenTheme$colors4.secondaryTextColor),
      headerTextColor: (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$dropdownM5 = nexenTheme.dropdownMenu) === null || _nexenTheme$dropdownM5 === void 0 ? void 0 : _nexenTheme$dropdownM5.headerTextColor) || (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$colors5 = nexenTheme.colors) === null || _nexenTheme$colors5 === void 0 ? void 0 : _nexenTheme$colors5.secondaryTextColor),
      itemTextColor: (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$dropdownM6 = nexenTheme.dropdownMenu) === null || _nexenTheme$dropdownM6 === void 0 ? void 0 : _nexenTheme$dropdownM6.itemTextColor) || (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$colors6 = nexenTheme.colors) === null || _nexenTheme$colors6 === void 0 ? void 0 : _nexenTheme$colors6.secondaryTextColor),
      itemSelectedColor: (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$dropdownM7 = nexenTheme.dropdownMenu) === null || _nexenTheme$dropdownM7 === void 0 ? void 0 : _nexenTheme$dropdownM7.itemSelectedColor) || (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$colors7 = nexenTheme.colors) === null || _nexenTheme$colors7 === void 0 ? void 0 : _nexenTheme$colors7.accentColor),
      textSize: (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$dropdownM8 = nexenTheme.dropdownMenu) === null || _nexenTheme$dropdownM8 === void 0 ? void 0 : _nexenTheme$dropdownM8.textSize) || (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$sizes = nexenTheme.sizes) === null || _nexenTheme$sizes === void 0 ? void 0 : _nexenTheme$sizes.secondaryTextSize),
      headerTextSize: (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$dropdownM9 = nexenTheme.dropdownMenu) === null || _nexenTheme$dropdownM9 === void 0 ? void 0 : _nexenTheme$dropdownM9.headerTextSize) || (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$sizes2 = nexenTheme.sizes) === null || _nexenTheme$sizes2 === void 0 ? void 0 : _nexenTheme$sizes2.secondaryTextSize),
      itemTextSize: (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$dropdownM10 = nexenTheme.dropdownMenu) === null || _nexenTheme$dropdownM10 === void 0 ? void 0 : _nexenTheme$dropdownM10.itemTextSize) || (nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$sizes3 = nexenTheme.sizes) === null || _nexenTheme$sizes3 === void 0 ? void 0 : _nexenTheme$sizes3.secondaryTextSize),
      cornerRadius: nexenTheme === null || nexenTheme === void 0 ? void 0 : (_nexenTheme$dropdownM11 = nexenTheme.dropdownMenu) === null || _nexenTheme$dropdownM11 === void 0 ? void 0 : _nexenTheme$dropdownM11.cornerRadius
    };
  }, [nexenTheme]);
  const containerStyle = {
    left: CONTAINER_HORIZONTAL_PADDING,
    right: CONTAINER_HORIZONTAL_PADDING,
    bottom: 0,
    paddingHorizontal: 0,
    paddingVertical: 0
  };

  const _onTextItemSelect = item => {
    const selectedTrack = {
      type: (selectedTextTrack === null || selectedTextTrack === void 0 ? void 0 : selectedTextTrack.type) || 'title',
      value: item.value
    };
    onTextTrackSelect === null || onTextTrackSelect === void 0 ? void 0 : onTextTrackSelect(selectedTrack);
    setSelectedTextItem(item);
  };

  const _onAudioItemSelect = item => {
    const selectedTrack = {
      type: (selectedAudioTrack === null || selectedAudioTrack === void 0 ? void 0 : selectedAudioTrack.type) || 'title',
      value: item.value
    };
    onAudioTrackSelect === null || onAudioTrackSelect === void 0 ? void 0 : onAudioTrackSelect(selectedTrack);
    setSelectedAudioItem(item);
  };

  React.useEffect(() => {
    if (textTracks && textTracks.length > 0) {
      const newItems = [{
        label: 'None',
        value: 'none'
      }];
      textTracks.forEach(item => {
        newItems.push({
          label: item.title,
          value: item.title
        });
      });
      setTextItems(newItems);
    }

    if (audioTracks && audioTracks.length > 0) {
      const newItems = [{
        label: 'None',
        value: 'none'
      }];
      audioTracks.forEach(item => {
        newItems.push({
          label: item.title,
          value: item.title
        });
      });
      setAudioItems(newItems);
    }
  }, [textTracks, audioTracks]);
  React.useEffect(() => {
    if (textTracks && selectedTextTrack) {
      const selected = textTracks.find(item => {
        if (selectedTextTrack.type !== 'system' && selectedTextTrack.type !== 'disabled') {
          return item[selectedTextTrack.type] === selectedTextTrack.value;
        }

        return false;
      });
      setSelectedTextItem({
        label: (selected === null || selected === void 0 ? void 0 : selected.title) || 'None',
        value: (selected === null || selected === void 0 ? void 0 : selected.title) || 'none'
      });
    }

    if (audioTracks && selectedAudioTrack) {
      const selected = audioTracks.find(item => {
        if (selectedAudioTrack.type !== 'system' && selectedAudioTrack.type !== 'disabled') {
          return item[selectedAudioTrack.type] === selectedAudioTrack.value;
        }

        return false;
      });
      setSelectedAudioItem({
        label: (selected === null || selected === void 0 ? void 0 : selected.title) || 'None',
        value: (selected === null || selected === void 0 ? void 0 : selected.title) || 'none'
      });
    }
  }, [selectedTextTrack, selectedAudioTrack]);
  return /*#__PURE__*/React.createElement(ModalView, {
    style: [styles.container, style, containerStyle]
  }, /*#__PURE__*/React.createElement(GradientView, {
    style: {
      height: '100%',
      width: '100%'
    },
    startOpacity: 0.0,
    middleOpacity: 0.2,
    endOpacity: 0.5
  }), /*#__PURE__*/React.createElement(View, {
    style: [styles.innerContainer, {
      flexDirection: 'row'
    }]
  }, /*#__PURE__*/React.createElement(View, {
    style: {
      flex: 1,
      marginRight: 5
    }
  }, /*#__PURE__*/React.createElement(DropDown, {
    height: dropdownHeight,
    label: 'Text Track',
    items: textItems,
    selectedItem: selectedTextItem,
    onItemSelect: _onTextItemSelect,
    theme: dropDownTheme
  })), /*#__PURE__*/React.createElement(View, {
    style: {
      flex: 1,
      marginLeft: 5
    }
  }, /*#__PURE__*/React.createElement(DropDown, {
    height: dropdownHeight,
    label: 'Audio Track',
    items: audioItems,
    selectedItem: selectedAudioItem,
    onItemSelect: _onAudioItemSelect,
    theme: dropDownTheme
  }))));
};

export default withAnimation(TrackControl);
const styles = StyleSheet.create({
  container: {
    overflow: 'hidden',
    zIndex: 110
  },
  innerContainer: {
    position: 'absolute',
    left: 0,
    top: 0,
    right: 0,
    bottom: 0,
    padding: 10
  }
});
//# sourceMappingURL=TrackControl.js.map